==> jc-1.4.0.tar.gz: polyglot/ext/jl/qq/QQNodeToken.h <==
// public class polyglot.ext.jl.qq.QQNodeToken

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4990d47df782d98e polyglot_ext_jl_qq_QQNodeToken
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Token

#include "polyglot/lex/Token.h"

#ifndef _JC_polyglot_ext_jl_qq_QQNodeToken_H_
#define _JC_polyglot_ext_jl_qq_QQNodeToken_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_qq_QQNodeToken$sub_refs	_jc_polyglot_ext_jl_qq_QQNodeToken$sub_refs;
typedef struct _jc_polyglot_ext_jl_qq_QQNodeToken$sub_nonrefs	_jc_polyglot_ext_jl_qq_QQNodeToken$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_QQNodeToken$refs	_jc_polyglot_ext_jl_qq_QQNodeToken$refs;
typedef struct _jc_polyglot_ext_jl_qq_QQNodeToken$nonrefs	_jc_polyglot_ext_jl_qq_QQNodeToken$nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_QQNodeToken$object	_jc_polyglot_ext_jl_qq_QQNodeToken$object;

typedef const struct _jc_polyglot_ext_jl_qq_QQNodeToken$vmethods	_jc_polyglot_ext_jl_qq_QQNodeToken$vmethods;
typedef const struct _jc_polyglot_ext_jl_qq_QQNodeToken$vtable	_jc_polyglot_ext_jl_qq_QQNodeToken$vtable;
typedef const struct _jc_polyglot_ext_jl_qq_QQNodeToken$vtype	_jc_polyglot_ext_jl_qq_QQNodeToken$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_qq_QQNodeToken$method$_init$d444315a9473577a(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQNodeToken$object *, struct _jc_polyglot_util_Position$object *, struct _jc_object *, jint);

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_qq_QQNodeToken$method$node$d01193f9f5e593ba(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQNodeToken$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_qq_QQNodeToken$method_info$node$d01193f9f5e593ba;

// Virtual methods structure
struct _jc_polyglot_ext_jl_qq_QQNodeToken$vmethods {
	struct _jc_object	*(*node$d01193f9f5e593ba)(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQNodeToken$object *);
};

// Vtable
struct _jc_polyglot_ext_jl_qq_QQNodeToken$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_ext_jl_qq_QQNodeToken$vmethods	polyglot_ext_jl_qq_QQNodeToken;
};

// Vtype
struct _jc_polyglot_ext_jl_qq_QQNodeToken$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_qq_QQNodeToken$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_QQNodeToken$sub_refs {
	struct _jc_object	*node;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_QQNodeToken$refs {
    _jc_polyglot_ext_jl_qq_QQNodeToken$sub_refs	polyglot_ext_jl_qq_QQNodeToken;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_QQNodeToken$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_QQNodeToken$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_ext_jl_qq_QQNodeToken$sub_nonrefs	polyglot_ext_jl_qq_QQNodeToken;
};

// Object instance structure
struct _jc_polyglot_ext_jl_qq_QQNodeToken$object {
	_jc_polyglot_ext_jl_qq_QQNodeToken$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_qq_QQNodeToken$vtype	*vtype;
	_jc_polyglot_ext_jl_qq_QQNodeToken$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_qq_QQNodeToken$vtype _jc_polyglot_ext_jl_qq_QQNodeToken$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_qq_QQNodeToken, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_qq_QQNodeToken$class_object;

#endif	/* _JC_polyglot_ext_jl_qq_QQNodeToken_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/qq/QQNodeToken.h <==
// public class polyglot.ext.jl.qq.QQNodeToken

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4990d47df782d98e polyglot_ext_jl_qq_QQNodeToken
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Token

#include "polyglot/lex/Token.h"

#ifndef _JC_polyglot_ext_jl_qq_QQNodeToken_H_
#define _JC_polyglot_ext_jl_qq_QQNodeToken_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_qq_QQNodeToken$sub_refs	_jc_polyglot_ext_jl_qq_QQNodeToken$sub_refs;
typedef struct _jc_polyglot_ext_jl_qq_QQNodeToken$sub_nonrefs	_jc_polyglot_ext_jl_qq_QQNodeToken$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_QQNodeToken$refs	_jc_polyglot_ext_jl_qq_QQNodeToken$refs;
typedef struct _jc_polyglot_ext_jl_qq_QQNodeToken$nonrefs	_jc_polyglot_ext_jl_qq_QQNodeToken$nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_QQNodeToken$object	_jc_polyglot_ext_jl_qq_QQNodeToken$object;

typedef const struct _jc_polyglot_ext_jl_qq_QQNodeToken$vmethods	_jc_polyglot_ext_jl_qq_QQNodeToken$vmethods;
typedef const struct _jc_polyglot_ext_jl_qq_QQNodeToken$vtable	_jc_polyglot_ext_jl_qq_QQNodeToken$vtable;
typedef const struct _jc_polyglot_ext_jl_qq_QQNodeToken$vtype	_jc_polyglot_ext_jl_qq_QQNodeToken$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_qq_QQNodeToken$method$_init$d444315a9473577a(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQNodeToken$object *, struct _jc_polyglot_util_Position$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_qq_QQNodeToken$method$node$d01193f9f5e593ba(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQNodeToken$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_qq_QQNodeToken$method_info$node$d01193f9f5e593ba;

// Virtual methods structure
struct _jc_polyglot_ext_jl_qq_QQNodeToken$vmethods {
	struct _jc_object	*(*node$d01193f9f5e593ba)(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQNodeToken$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_qq_QQNodeToken$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_ext_jl_qq_QQNodeToken$vmethods	polyglot_ext_jl_qq_QQNodeToken;
};

// Vtype
struct _jc_polyglot_ext_jl_qq_QQNodeToken$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_qq_QQNodeToken$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_QQNodeToken$sub_refs {
	struct _jc_object	*node;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_QQNodeToken$refs {
    _jc_polyglot_ext_jl_qq_QQNodeToken$sub_refs	polyglot_ext_jl_qq_QQNodeToken;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_QQNodeToken$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_QQNodeToken$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_ext_jl_qq_QQNodeToken$sub_nonrefs	polyglot_ext_jl_qq_QQNodeToken;
};

// Object instance structure
struct _jc_polyglot_ext_jl_qq_QQNodeToken$object {
	_jc_polyglot_ext_jl_qq_QQNodeToken$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_qq_QQNodeToken$vtype	*vtype;
	_jc_polyglot_ext_jl_qq_QQNodeToken$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_qq_QQNodeToken$vtype _jc_polyglot_ext_jl_qq_QQNodeToken$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_qq_QQNodeToken, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_qq_QQNodeToken$class_object;

#endif	/* _JC_polyglot_ext_jl_qq_QQNodeToken_H_ */
